# img_processing

Description. 
The package img_processing is used to:
	- Processing:
		- Histogram matching
		- Structural similarity
		- Resize image
		- Utils:
		- Read Image
		- Save Image
		- Plot Image
		- Plot Result
		- Plot Histogram
		-

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install img_processing

```bash
pip install img_processing
```

## Author
Felipe F. Porto

## License
[MIT](https://choosealicense.com/licenses/mit/)